@@ -21,8 +21,9 @@
 
 #include "spinner.h"
 
-#include <QProcess>
 #include <string>
+#include <sys/types.h>
+#include <mutex>
 
 namespace usc
 {
@@ -41,7 +42,8 @@ public:
 private:
     std::string const executable;
     std::string const mir_socket;
-    QProcess process;
+    std::mutex mutex;
+    pid_t spinner_pid;
 };
 
 }
