@@ -39,6 +39,7 @@ class Spinner;
 class SessionSwitcher;
 class DMMessageHandler;
 class DMConnection;
+class PerformanceBooster;
 class Screen;
 class ScreenHardware;
 class UnityScreenService;
@@ -61,6 +62,7 @@ public:
     using mir::Server::the_compositor;
     using mir::Server::the_touch_visualizer;
 
+    virtual std::shared_ptr<PerformanceBooster> the_performance_booster();
     virtual std::shared_ptr<Spinner> the_spinner();
     virtual std::shared_ptr<DMMessageHandler> the_dm_message_handler();
     virtual std::shared_ptr<DMConnection> the_dm_connection();
